

bl_info = {
    "name": "SpeedTree stmat format",
    "author": "SpeedTree",
    "version": (1, 0, 0),
    "blender": (2, 80, 0),
    "location": "File > Import-Export",
    "description": "Import STMAT files",
    "warning": "",
    "wiki_url": "https://www.speedtree.com",
    "category": "Import-Export"}

if "bpy" in locals():
    import importlib
    if "import_stmat" in locals():
        importlib.reload(import_stmat)

import os
import bpy
from bpy.props import (
    CollectionProperty,
    StringProperty,
    BoolProperty,
    EnumProperty,
    FloatProperty,
)
from bpy_extras.io_utils import (
    ImportHelper
)

class ImportSTMAT(bpy.types.Operator, ImportHelper):
    """Load a SpeedTree STMAT File"""
    bl_idname = "import_tree.stmat"
    bl_label = "Import STMAT"
    bl_options = {'PRESET', 'UNDO'}

    files: CollectionProperty(
        name="File Path",
        description=(
            "File path used for importing "
            "the STMAT file"
        ),
        type=bpy.types.OperatorFileListElement)

    directory: StringProperty()

    filename_ext = ".stmat"
    filter_glob: StringProperty(default="*.stmat", options={'HIDDEN'})

    def execute(self, context):
        paths = [os.path.join(self.directory, name.name)
                 for name in self.files]
        if not paths:
            paths.append(self.filepath)

        from . import import_stmat

        for path in paths:
            import_stmat.load(self, context, path)

        return {'FINISHED'}


def menu_func_import(self, context):
    self.layout.operator(ImportSTMAT.bl_idname, text="SpeedTree (.stmat)")

def register():
    bpy.utils.register_class(ImportSTMAT)
    bpy.types.TOPBAR_MT_file_import.append(menu_func_import)

def unregister():
    bpy.types.TOPBAR_MT_file_import.remove(menu_func_import)
    bpy.utils.unregister_class(ImportSTMAT)

if __name__ == "__main__":
    register()
